@@ -1144,6 +1144,7 @@ waitevent:
 			if( (ev.type == LIQEVENT_TYPE_KEY) && (ev.state==LIQEVENT_STATE_PRESS) && (ev.key.keycode==65307) )	//ESC
 			{
 				liqapp_log("Escape Pressed, Cancelling");
+				savethumb( self );
 				//running=0;
 				if(fadestartx || fadestarty)
 				{	fademode=-1;  fadeatx=0; fadeaty=0; }
@@ -1270,7 +1271,7 @@ waitevent:
 				// get hold of actual coordinates...
 				int mx=ev.mouse.x;
 				int my=ev.mouse.y;
-				liqapp_log("event mouse scrn (%i,%i)",mx,my);
+			//	liqapp_log("event mouse scrn (%i,%i)",mx,my);
 			
 				mx -= fadeatx;	// let this have its position adjusted
 				my -= fadeaty;
@@ -1281,7 +1282,7 @@ waitevent:
 				wy=0;
 
 				vgraph_convert_target2window(graph ,mx,my,  &wx,&wy);
-				liqapp_log("mouse scrn (%i,%i)   cell (%i,%i)",mx,my,  wx,wy);
+			//	liqapp_log("mouse scrn (%i,%i)   cell (%i,%i)",mx,my,  wx,wy);
 				
 
 				hotx=0;
@@ -2036,7 +2037,7 @@ moar:
 
 			
 			vgraph_drawcell(graph,x,y,w,h,self);
-			
+		
 			//liqapp_log("render adding nav items");
 			static liqimage *infoback=NULL;
 			static liqimage *infoclose=NULL;
