@@ -18,6 +18,9 @@
 #include "liqcell_easyrun.h"
 #include "liqcell_easyhandler.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 //#####################################################################
 //#####################################################################
@@ -110,16 +113,6 @@ liqcell *liqtimer_create()
 	{
 		
 		// todo: should make sure we break out of duldrums if the user enables or disables us
-		
-		liqcell *meta = mkmeta_group(
-							mkmeta_title(        "liqtimer"),
-							mkmeta_description(  "a small control to send repeated liqtimer events"),
-							mkmeta_author(       "liquid@gmail.com"),
-							mkmeta_version(      "1.0"),
-							NULL);
-
-
-
 		liqcell_setvisible(self,0);	// not visible in the render window ever
 		liqcell_setenabled(self,0);
 		liqcell_propseti(self,"timerinterval",100);
@@ -127,7 +120,7 @@ liqcell *liqtimer_create()
 
 
 
-				pthread_t 		*tid = malloc(sizeof(pthread_t));
+				pthread_t 		*tid = (pthread_t *)malloc(sizeof(pthread_t));
 				if(!tid)
 				{
 					liqapp_log("liqtimer, cannot alloc thread");
@@ -151,55 +144,7 @@ liqcell *liqtimer_create()
 	return self;
 }
 
-
-
-
-//#####################################################################
-//#####################################################################
-//##################################################################### main :)
-//#####################################################################
-//#####################################################################
-
-// this is only used when liqtreebrowse is compiled as a standalone binary
-// otherwise it can be constructed as a widget and exist with exactly the same lifespan
-
-static void liqcell_easyrun_internal(liqcell *dialog)
-{
-	// 20090414_210111 lcuk : very simple test of an easyrun automaticl opening wrapper
-	// 20090414_210124 lcuk : it is clear to me now that easyrun itself should maintain a stack of the items it is currently
-	// 20090414_210144 lcuk : showing and in that it willalso be able to list them and show them properly
-	
-	if(0!=liqcanvas_init( 800,480, 1))
-	{
-		liqapp_errorandfail(-1,"canvas Init");
-		//closeall();
-		return -1;
-	}
-		
-	liqcell_easyrun( dialog );
-		
-	liqcanvas_close();
-
+#ifdef __cplusplus
 }
-
-int main (int argc, char* argv[])
-{
-	if(liqapp_init(   argc,argv ,"liqtimer" ,"0.0.1") != 0)
-	{
-		{ return liqapp_errorandfail(-1,"liqtimer liqapp_init failed"); }
-	}
-
-	liqcell *self = liqtimer_create();
-	liqcell_easyrun_internal(self);
-	liqcell_release(self);
-	liqapp_close();
-
-	return 0;
-}
-
-
-
-
-
-
+#endif
 
